summaryrefslogtreecommitdiff
path: root/src/include/nodes/relation.h
diff options
context:
space:
mode:
authorBruce Momjian <bruce@momjian.us>1999-02-12 06:43:53 +0000
committerBruce Momjian <bruce@momjian.us>1999-02-12 06:43:53 +0000
commitc0d17c7aee68bb73140d11dc03973157e6ca7e76 (patch)
treee973403fc12f201021ac3a379baa859eed7c9308 /src/include/nodes/relation.h
parent3fdb9bb9c74afa79f574438cbbf5178d30463bb6 (diff)
downloadpostgresql-c0d17c7aee68bb73140d11dc03973157e6ca7e76.tar.gz
JoinPath -> NestPath for nested loop.
Diffstat (limited to 'src/include/nodes/relation.h')
-rw-r--r--src/include/nodes/relation.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/include/nodes/relation.h b/src/include/nodes/relation.h
index 966f73732b..567a810e73 100644
--- a/src/include/nodes/relation.h
+++ b/src/include/nodes/relation.h
@@ -6,7 +6,7 @@
*
* Copyright (c) 1994, Regents of the University of California
*
- * $Id: relation.h,v 1.20 1999/02/12 05:57:01 momjian Exp $
+ * $Id: relation.h,v 1.21 1999/02/12 06:43:47 momjian Exp $
*
*-------------------------------------------------------------------------
*/
@@ -160,17 +160,17 @@ typedef struct IndexPath
int *indexkeys; /* to transform heap attnos into index ones */
} IndexPath;
-typedef struct JoinPath
+typedef struct NestPath
{
Path path;
List *pathinfo;
Path *outerjoinpath;
Path *innerjoinpath;
-} JoinPath;
+} NestPath;
typedef struct MergePath
{
- JoinPath jpath;
+ NestPath jpath;
List *path_mergeclauses;
List *outersortkeys;
List *innersortkeys;
@@ -178,7 +178,7 @@ typedef struct MergePath
typedef struct HashPath
{
- JoinPath jpath;
+ NestPath jpath;
List *path_hashclauses;
List *outerhashkeys;
List *innerhashkeys;
@@ -262,7 +262,7 @@ typedef struct Iter
/*
** Stream:
** A stream represents a root-to-leaf path in a plan tree (i.e. a tree of
** JoinPaths and Paths). The stream includes pointers to all Path nodes,
** as well as to any clauses that reside above Path nodes. This structure
** is used to make Path nodes and clauses look similar, so that Predicate
** Migration can run.
@@ -262,7 +262,7 @@ typedef struct Iter
** Stream:
** A stream represents a root-to-leaf path in a plan tree (i.e. a tree of
-** JoinPaths and Paths). The stream includes pointers to all Path nodes,
+** NestPaths and Paths). The stream includes pointers to all Path nodes,
** as well as to any clauses that reside above Path nodes. This structure
** is used to make Path nodes and clauses look similar, so that Predicate